@@ -1,11 +1,11 @@
-import vegaapiclient as vac
+from google.protobuf.empty_pb2 import Empty
 
 from .fixtures import tradingdataGRPC, tradingdataREST  # noqa: F401
 
 
 def test_MarketsData(tradingdataGRPC, tradingdataREST):  # noqa: F811
-    g = tradingdataGRPC.MarketsData(vac.grpc.api.trading.MarketsDataResponse())
-    r = tradingdataREST.MarketsData()
+    g = tradingdataGRPC.MarketsData(Empty())
+    r = tradingdataREST.MarketsData(Empty())
 
     # The order (of MarketData objects in the list) is not guaranteed.
     gIDs = set(md.market for md in g.marketsData)
